//[mahjong-utils](../../../index.md)/[mahjongutils.models](../index.md)/[Toitsu](index.md)/[second](second.md)

# second

[common]\
open override val [second](second.md): [Tile](../-tile/index.md)

第二张牌
